Layer

Trait Layer 

pub trait Layer {
    // Required methods
    fn source(&self) -> SourceKind;
    fn load(&self, ctx: &LayerCtx) -> Result<LayerOutput, LayerError>;
}
A source of configuration values.

Required Methods

fn source(&self) -> SourceKind

Which kind of place this reads. Used by the scope check and reported by explain.

fn load(&self, ctx: &LayerCtx) -> Result<LayerOutput, LayerError>

Everything this layer has to say, in one pass.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors