spec_kdl

Function spec_kdl 

pub fn spec_kdl(props: &[PropMeta]) -> String
The spec config block for these settings, as KDL.

Ends with a newline, so it can be appended to an emitted spec as-is. Props are written in registry order, which for a derived registry is declaration order.